# RPGツクールMV CastleDBプラグイン
RPGツクールMVのプラグインです。  
導入することで、RPGツクールMV上でCastleDBのデータを利用することができるようになります。

## CastleDBについて
jsonベースのゲーム用データベースエディタです。  
詳細は下記リンクを参照してください。  
http://castledb.org/

## 使い方
CastleDB.jsを導入対象プロジェクトのjs/pluginsフォルダへコピーし、プラグインを有効化してください。  

### パラメータ
- Auto Load  
  自動ロード機能の有効状態です。(デフォルト値:true)。  
  有効時は$cdbへ自動的にロード処理が行われます。
- Data Path  
  TESイベントパッチファイルの格納先です(デフォルト値:"./data/Data.cdb")。
- Image Path  
  imgファイルの格納先です(デフォルト値: "./data/Data.img")。

## 関数リファレンス
このプラグインはプラグインコマンドで操作することはできません。  
ゲームエンジン上にCastleDBを操作するクラスが追加されるため、スクリプト上から操作を行ってください。

### CastleDBManager()
CastleDBの入出力を管理するクラスです。

#### CastleDBManager.load(dataPath, imagePath)
DBファイルをロードします。  

- dataPath - データファイルのパスです。  
- imagePath - イメージファイルのパスです。  

#### CastleDBManager.prototype.getIdentifier(sheetName)
シートに存在するIDの項目名を取得します。  

- sheetName - シート名を指定します。  

#### CastleDBManager.prototype.getLines(sheetName)
シートに存在するレコードの一覧を配列で取得します。  

- sheetName - シート名を指定します。  

#### CastleDBManager.prototype.getLine(sheetName, id)
シートに存在するレコードを取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  

#### CastleDBManager.prototype.getValue(sheetName, id, columnName)
レコードの値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getItem(sheetName, id)
レコードのアイテムオブジェクトを取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  

#### CastleDBManager.prototype.getEnumValue(sheetName, id, columnName)
列挙体選択値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getFlagValues(sheetName, id, columnName)
フラグ選択値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getReferenceItem(sheetName, id, columnName)
参照型アイテムオブジェクトを取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getReferenceValue(sheetName, id, columnName, refColumnName)
参照型アイテムオブジェクトの値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  
- refColumnName - 参照型レコードのインデックス、またはIDを指定します。  

#### CastleDBManager.prototype.getListItems(sheetName, id, columnName)
リスト型アイテムオブジェクトの一覧を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getListItem(sheetName, id, columnName, listId)
リスト型アイテムオブジェクトの行のアイテムオブジェクトを取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  
- listId - リストレコードのインデックス、またはIDを指定します。  

#### CastleDBManager.prototype.getListValue(sheetName, id, columnName, listId, listColumnName)
リスト型アイテムオブジェクトの行の値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  
- listId - リストレコードのインデックス、またはIDを指定します。  
- listColumnName リストレコードのカラム名を指定します。  

#### CastleDBManager.prototype.getColor(sheetName, id, columnName)
カラー型の値を取得します。カラー型はRGBの配列で取得されます。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getCustomType(sheetName, id, columnName)
ユーザ定義型の値を取得します。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  

#### CastleDBManager.prototype.getImage(sheetName, id, columnName, hue)
画像型の値を取得します。画像型はBitmapで取得されます。  

- sheetName - シート名を指定します。  
- id - レコードのインデックス、またはIDを指定します。  
- columnName - カラム名を指定します。  
- hue - 画像の色調。  

### CastleDBManagerItem(manager, sheetName, line)
CastleDBのレコード値のクラスです。  

- manager - CastleDBManagerのインスタンスを指定します。  
- sheetName - シート名を指定します  
- line - レコード行のデータを指定します。  

#### CastleDBManagerItem.prototype.getLine()
レコードの実体を取得します。  

#### CastleDBManagerItem.prototype.getValue(columnName)
レコードの値を取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getEnumValue(columnName)
列挙体選択値を取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getFlagValues(columnName)
フラグ選択値を取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getReferenceItem(columnName)
参照型アイテムオブジェクトを取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getReferenceValue(columnName, refColumnName)
参照型アイテムオブジェクトの値を取得します。  

- columnName - カラム名を指定します。  
- refColumnName - 参照型レコードのインデックス、またはIDを指定します。  

#### CastleDBManagerItem.prototype.getListItems(columnName)
リスト型アイテムオブジェクトの一覧を取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getListItem(columnName, id)
リスト型アイテムオブジェクトの行のアイテムオブジェクトを取得します。  

- columnName - カラム名を指定します。  
- id - リストレコードのインデックス、またはIDを指定します。  

#### CastleDBManagerItem.prototype.getListValue(columnName, id, listColumnName)
リスト型アイテムオブジェクトの行の値を取得します。  

- columnName - カラム名を指定します。  
- id - リストレコードのインデックス、またはIDを指定します。  
- listColumnName リストレコードのカラム名を指定します。  

#### CastleDBManagerItem.prototype.getColor(columnName)
カラー型の値を取得します。カラー型はRGBの配列で取得されます。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getCustomType(columnName)
ユーザ定義型の値を取得します。  

- columnName - カラム名を指定します。  

#### CastleDBManagerItem.prototype.getImage(columnName, hue)
画像型の値を取得します。画像型はBitmapで取得されます。  

- columnName - カラム名を指定します。  
- hue - 画像の色調。  

## ライセンス
The MIT License (MIT)
